#####################################################################
### Read in all .wav files and .TextGrid files in list_files.txt
### Give formant values in the interval specified in the .TextGrid
### with a step specified in variable 'time_step'
###
### Takes list_files.txt as input with a list of .wav files to process
### Creates one xxxx.frm per file in list_files.txt
###
### Hlne Loevenbruck
### April 2003
#####################################################################

# Formant parameters
# to specify:
# time_step: formant analysis step (in s)
# nb_formant: max number of formants to be detected
# max_value: max formant value (in Hz)
# win_length: window length: the narrower the window, 
# the better the temporal resolution, i.e. the more constrasted the formants are
# pre_emph: pre-emphasis from e.g. 50 Hz 

time_step =  0.01
nb_formant = 7
max_value = 8000
win_length = 0.025
pre_emph = 50

#Loop on all files in list_files.txt 
###########################

#Read Strings from raw text file... list_files.txt
#nb_files = Get number of strings

#for item from 1 to nb_files
#   select Strings list_files

   # Read .wav file name
   # Build .TextGrid name from root name
   #----------------------------------------------------------
   #file_name$ = Get string... item
   file_name$ = "E:\Temp\loc57_pre.wav"
   root$ =  file_name$ - ".wav"
   text_name$ = root$ + ".TextGrid"
   formant_file$ = root$ + ".frm"
   filedelete 'formant_file$'

   # Read 'Begin' and 'End' instants in .textGrid file
   #-------------------------------------------------------------------------
   Read from file... 'text_name$'   
   select TextGrid 'root$'
   instant_begin = Get starting point... 1 2
   instant_end = Get end point... 1 2

   # Compute formants
   #-----------------------------
   Read from file... 'file_name$'
   select Sound  'root$'
   To Formant (burg)... 'time_step' 'nb_formant' 'max_value' 'win_length' 'pre_emph'
     
   frame_begin = Get frame from time... 'instant_begin'
   frame_end = Get frame from time... 'instant_end'

   for i from 'frame_begin' to 'frame_end' +1

  	t_frame = Get time from frame... i
   	f1= Get value at time... 1 't_frame' Hertz Linear
   	f2= Get value at time... 2 't_frame' Hertz Linear
   	f3= Get value at time... 3 't_frame' Hertz Linear
   	f4= Get value at time... 4 't_frame' Hertz Linear
   	f5= Get value at time... 5 't_frame' Hertz Linear
   	f6= Get value at time... 6 't_frame' Hertz Linear
   	f7= Get value at time... 7 't_frame' Hertz Linear

   	# Write formant values to formant file xxxx.frm
   	fileappend 'formant_file$' 'f1' 'tab$'  'f2' 'tab$' 'f3' 'tab$' 'f4'  'tab$' 'f5' 'tab$' 'f6'  'tab$' 'f7' 'newline$'
  
   endfor

#endfor
